import { CSSProperties } from 'react';
import { ThemeRef } from 'treat';
export interface ScaleTokens<T extends keyof CSSProperties> {
    [key: string]: NonNullable<CSSProperties[T]>;
}
export interface CommonTheme {
    breakpoints: number[];
    shorthands: {
        [key: string]: Array<keyof CSSProperties>;
    };
    aliases: {
        [key: string]: keyof CSSProperties | keyof CommonTheme['shorthands'];
    };
}
export interface RuntimeTheme extends CommonTheme {
    ref: ThemeRef;
}
export interface StaticTheme extends CommonTheme {
    scales: {
        spacing?: ScaleTokens<'margin'>;
        size?: ScaleTokens<'width'>;
        fontFamily?: ScaleTokens<'fontFamily'>;
        fontSize?: ScaleTokens<'fontSize'>;
        fontWeight?: ScaleTokens<'fontWeight'>;
        lineHeight?: ScaleTokens<'lineHeight'>;
        color?: ScaleTokens<'color'>;
        letterSpacing?: ScaleTokens<'letterSpacing'>;
        border?: ScaleTokens<'border'>;
        borderWidth?: ScaleTokens<'borderWidth'>;
        radius?: ScaleTokens<'borderRadius'>;
        shadow?: ScaleTokens<'boxShadow'>;
        opacity?: ScaleTokens<'opacity'>;
        zIndex?: ScaleTokens<'zIndex'>;
    };
    resolvers: {
        [key in keyof CSSProperties]: keyof StaticTheme['scales'];
    };
}
export declare function createTheme(tokens: StaticTheme, localDebugName?: string): RuntimeTheme;
export declare const defaultTheme: StaticTheme;
